@@ -120,6 +120,7 @@ test_that("presets list fun",{
 
 test_that("rePort produces a report",{
   skip_on_cran()
+  testthat::skip_if_not_installed("rmarkdown")
   browser <- options(browser=function(url) message(url))
   on.exit(options(browser))
   
@@ -156,6 +157,8 @@ test_that("reView-withoutset",{
   # One has also have PhantomJS work with the firewall
   
   skip_on_cran() # no shinytest on cran
+  skip_on_os("mac") # shinytest ci on macos is unstable for some reason
+  testthat::skip_if_not_installed("shiny")
   testthat::skip_if_not_installed("shinytest")
   
   app <- shinytest::ShinyDriver$new(test_path("shiny-withoutset"),
@@ -408,6 +411,8 @@ test_that("reView-setcoefconst",{
   # One has also have PhantomJS work with the firewall
   
   skip_on_cran() # no shinytest on cran
+  skip_on_os("mac") # shinytest ci on macos is unstable for some reason
+  testthat::skip_if_not_installed("shiny")
   testthat::skip_if_not_installed("shinytest")
   
   app <- shinytest::ShinyDriver$new(test_path("shiny-setcoefconst"),
@@ -503,6 +508,8 @@ test_that("reView-outliers",{
   # One has also have PhantomJS work with the firewall
   
   skip_on_cran() # no shinytest on cran
+  skip_on_os("mac") # shinytest ci on macos is unstable for some reason
+  testthat::skip_if_not_installed("shiny")
   testthat::skip_if_not_installed("shinytest")
   
   app <- shinytest::ShinyDriver$new(test_path("shiny-outliers"),
@@ -573,6 +580,8 @@ test_that("reView-outlierssetcoef",{
   # One has also have PhantomJS work with the firewall
   
   skip_on_cran() # no shinytest on cran
+  skip_on_os("mac") # shinytest ci on macos is unstable for some reason
+  testthat::skip_if_not_installed("shiny")
   testthat::skip_if_not_installed("shinytest")
   
   app <- shinytest::ShinyDriver$new(test_path("shiny-outlierssetcoef"),
